@@ -40,24 +40,17 @@
 #include <moveit/robot_model/robot_model.h>
 #include <moveit/robot_state/conversions.h>
 
+#include <rclcpp/logger.hpp>
+#include <rclcpp/logging.hpp>
 #include <eigen3/Eigen/Core>
 #include <eigen3/Eigen/LU>
 #include <random>
 #include <visualization_msgs/msg/marker_array.hpp>
 
-#include "rclcpp/rclcpp.hpp"
-
 namespace chomp
 {
 static const rclcpp::Logger LOGGER = rclcpp::get_logger("chomp_optimizer");
 
-double getRandomDouble()
-{
-  std::default_random_engine seed;
-  std::uniform_real_distribution<> uniform(0.0, 1.0);
-  return uniform(seed);
-}
-
 ChompOptimizer::ChompOptimizer(ChompTrajectory* trajectory, const planning_scene::PlanningSceneConstPtr& planning_scene,
                                const std::string& planning_group, const ChompParameters* parameters,
                                const moveit::core::RobotState& start_state)
@@ -318,7 +311,7 @@ bool ChompOptimizer::optimize()
     double s_cost = getSmoothnessCost();
     double cost = c_cost + s_cost;
 
-    RCLCPP_INFO(LOGGER, "Collision cost %f, smoothness cost: %f", c_cost, s_cost);
+    RCLCPP_DEBUG(LOGGER, "Collision cost %f, smoothness cost: %f", c_cost, s_cost);
 
     /// TODO: HMC BASED COMMENTED CODE BELOW, Need to uncomment and perform extensive testing by varying the HMC
     /// parameters values in the chomp_planning.yaml file so that CHOMP can find optimal paths
@@ -335,7 +328,7 @@ bool ChompOptimizer::optimize()
     //       averageCostVelocity += (costs.at(i) - costs.at(i - 1));
     //     }
 
-    //     averageCostVelocity /= (double)(costWindow);
+    //     averageCostVelocity /= static_cast<double>(costWindow);
     //     currentCostIter = -1;
     //   }
     // }
@@ -378,7 +371,7 @@ bool ChompOptimizer::optimize()
 
     if (iteration_ % 10 == 0)
     {
-      RCLCPP_INFO(LOGGER, "iteration: %d", iteration_);
+      RCLCPP_DEBUG(LOGGER, "iteration: %d", iteration_);
       if (isCurrentTrajectoryMeshToMeshCollisionFree())
       {
         num_collision_free_iterations_ = 0;
@@ -425,7 +418,7 @@ bool ChompOptimizer::optimize()
       }
       else
       {
-        RCLCPP_INFO(LOGGER, "cCost %f over threshold %f", c_cost, parameters_->collision_threshold_);
+        RCLCPP_DEBUG(LOGGER, "cCost %f over threshold %f", c_cost, parameters_->collision_threshold_);
       }
     }
 
@@ -610,7 +603,7 @@ void ChompOptimizer::calculateCollisionIncrements()
   // This is faster and guaranteed to converge, but it may take more iterations in the worst case.
   if (parameters_->use_stochastic_descent_)
   {
-    start_point = static_cast<int>(getRandomDouble() * (free_vars_end_ - free_vars_start_) + free_vars_start_);
+    start_point = static_cast<int>(rsl::uniform_real(0., 1.) * (free_vars_end_ - free_vars_start_) + free_vars_start_);
     if (start_point < free_vars_start_)
       start_point = free_vars_start_;
     if (start_point > free_vars_end_)
@@ -1069,9 +1062,9 @@ void ChompOptimizer::perturbTrajectory()
 //     int j = 0;
 //     for(map<string, pair<double, double> >::iterator it = bounds.begin(); it != bounds.end(); ++it)
 //     {
-//       double randVal = jointState->getJointStateValues()[j] + (getRandomDouble()
+//       double randVal = jointState->getJointStateValues()[j] + (rsl::uniform_real(0., 1.)
 //                                                                * (parameters_->getRandomJumpAmount()) -
-//                                                                getRandomDouble() *
+//                                                                rsl::uniform_real(0., 1.) *
 //                                                                (parameters_->getRandomJumpAmount()));
 
 //       if(!continuous)
